@@ -60,6 +60,9 @@ static void do_group (char **args);
 static void do_extent (char **args);
 static void do_chroot (char **args);
 static void do_slotmap (char **args);
+static void do_encode_lockres (char **args);
+static void do_locate (char **args);
+static void do_fs_locks (char **args);
 
 dbgfs_gbls gbls;
 
@@ -71,11 +74,13 @@ static Command commands[] = {
 	{ "curdev",	do_curdev },
 	{ "dump",	do_dump },
 	{ "extent",	do_extent },
+	{ "fs_locks",	do_fs_locks },
 	{ "group",	do_group },
 	{ "help",	do_help },
 	{ "hb",		do_hb },
 	{ "?",		do_help },
 	{ "lcd",	do_lcd },
+	{ "locate",	do_locate },
 	{ "logdump",	do_logdump },
 	{ "ls",		do_ls },
 	{ "open",	do_open },
@@ -84,7 +89,8 @@ static Command commands[] = {
 	{ "rdump",	do_rdump },
 	{ "slotmap",	do_slotmap },
 	{ "stat",	do_stat },
-	{ "stats",	do_stats }
+	{ "stats",	do_stats },
+	{ "encode",	do_encode_lockres }
 };
 
 /*
@@ -271,7 +277,7 @@ static int process_inodestr_args(char **args, uint64_t *blkno)
  */
 static int get_slotnum(char **args, uint16_t *slotnum)
 {
-	ocfs2_super_block *sb = OCFS2_RAW_SB(gbls.fs->fs_super);
+	struct ocfs2_super_block *sb = OCFS2_RAW_SB(gbls.fs->fs_super);
 	char *endptr;
 
 	if (args[1]) {
@@ -295,10 +301,10 @@ static int get_slotnum(char **args, uint16_t *slotnum)
  * traverse_extents()
  *
  */
-static errcode_t traverse_extents (ocfs2_filesys *fs, ocfs2_extent_list *el, FILE *out)
+static errcode_t traverse_extents (ocfs2_filesys *fs, struct ocfs2_extent_list *el, FILE *out)
 {
-	ocfs2_extent_block *eb;
-	ocfs2_extent_rec *rec;
+	struct ocfs2_extent_block *eb;
+	struct ocfs2_extent_rec *rec;
 	errcode_t ret = 0;
 	char *buf = NULL;
 	int i;
@@ -316,7 +322,7 @@ static errcode_t traverse_extents (ocfs2_filesys *fs, ocfs2_extent_list *el, FIL
 			if (ret)
 				goto bail;
 
-			eb = (ocfs2_extent_block *)buf;
+			eb = (struct ocfs2_extent_block *)buf;
 
 			dump_extent_block (out, eb);
 
@@ -336,10 +342,10 @@ bail:
  * traverse_chains()
  *
  */
-static errcode_t traverse_chains (ocfs2_filesys *fs, ocfs2_chain_list *cl, FILE *out)
+static errcode_t traverse_chains (ocfs2_filesys *fs, struct ocfs2_chain_list *cl, FILE *out)
 {
-	ocfs2_group_desc *grp;
-	ocfs2_chain_rec *rec;
+	struct ocfs2_group_desc *grp;
+	struct ocfs2_chain_rec *rec;
 	errcode_t ret = 0;
 	char *buf = NULL;
 	uint64_t blkno;
@@ -362,7 +368,7 @@ static errcode_t traverse_chains (ocfs2_filesys *fs, ocfs2_chain_list *cl, FILE
 			if (ret)
 				goto bail;
 
-			grp = (ocfs2_group_desc *)buf;
+			grp = (struct ocfs2_group_desc *)buf;
 			dump_group_descriptor(out, grp, index);
 			blkno = grp->bg_next_group;
 			index++;
@@ -387,7 +393,7 @@ static void do_open (char **args)
 	errcode_t ret = 0;
 	char sysfile[SYSTEM_FILE_NAME_MAX];
 	int i;
-	ocfs2_super_block *sb;
+	struct ocfs2_super_block *sb;
 
 	if (gbls.device)
 		do_close (NULL);
@@ -580,10 +586,13 @@ static void do_help (char **args)
 	printf ("close\t\t\t\t\tClose a device\n");
 	printf ("curdev\t\t\t\t\tShow current device\n");
 	printf ("dump [-p] <filespec> <outfile>\t\tDumps file to outfile on a mounted fs\n");
+	printf ("encode <filespec>\t\t\tShow lock name\n");
 	printf ("extent <block#>\t\t\t\tShow extent block\n");
+	printf ("fs_locks [-l]\t\t\t\tShow live fs locking state\n");
 	printf ("group <block#>\t\t\t\tShow chain group\n");
 	printf ("help, ?\t\t\t\t\tThis information\n");
 	printf ("lcd <directory>\t\t\t\tChange directory on a mounted flesystem\n");
+	printf ("locate <filespec>\t\t\tList all paths to the inode\n");
 	printf ("logdump <slot#>\t\t\t\tPrints journal file for the node slot\n");
 	printf ("ls [-l] <filespec>\t\t\tList directory\n");
 	printf ("open <device>\t\t\t\tOpen a device\n");
@@ -651,8 +660,8 @@ static void do_stats (char **args)
 {
 	char *opts = args[1];
 	FILE *out;
-	ocfs2_dinode *in;
-	ocfs2_super_block *sb;
+	struct ocfs2_dinode *in;
+	struct ocfs2_super_block *sb;
 
 	if (check_device_open())
 		goto bail;
@@ -677,7 +686,7 @@ bail:
  */
 static void do_stat (char **args)
 {
-	ocfs2_dinode *inode;
+	struct ocfs2_dinode *inode;
 	uint64_t blkno;
 	char *buf = NULL;
 	FILE *out;
@@ -693,7 +702,7 @@ static void do_stat (char **args)
 		return ;
 	}
 
-	inode = (ocfs2_dinode *)buf;
+	inode = (struct ocfs2_dinode *)buf;
 
 	out = open_pager(gbls.interactive);
 	dump_inode(out, inode);
@@ -813,7 +822,7 @@ static void do_cat (char **args)
 	uint64_t blkno;
 	errcode_t ret;
 	char *buf;
-	ocfs2_dinode *di;
+	struct ocfs2_dinode *di;
 
 	if (process_inode_args(args, &blkno))
 		return ;
@@ -825,7 +834,7 @@ static void do_cat (char **args)
 		return ;
 	}
 
-	di = (ocfs2_dinode *)buf;
+	di = (struct ocfs2_dinode *)buf;
 	if (!S_ISREG(di->i_mode)) {
 		fprintf(stderr, "%s: Not a regular file\n", args[0]);
 		return ;
@@ -881,7 +890,7 @@ bail:
  */
 static void do_group (char **args)
 {
-	ocfs2_group_desc *grp;
+	struct ocfs2_group_desc *grp;
 	uint64_t blkno;
 	char *buf = NULL;
 	FILE *out;
@@ -901,7 +910,7 @@ static void do_group (char **args)
 			return ;
 		}
 
-		grp = (ocfs2_group_desc *)buf;
+		grp = (struct ocfs2_group_desc *)buf;
 		dump_group_descriptor(out, grp, index);
 		blkno = grp->bg_next_group;
 		index++;
@@ -918,7 +927,7 @@ static void do_group (char **args)
  */
 static void do_extent (char **args)
 {
-	ocfs2_extent_block *eb;
+	struct ocfs2_extent_block *eb;
 	uint64_t blkno;
 	char *buf = NULL;
 	FILE *out;
@@ -934,7 +943,7 @@ static void do_extent (char **args)
 		return ;
 	}
 
-	eb = (ocfs2_extent_block *)buf;
+	eb = (struct ocfs2_extent_block *)buf;
 
 	out = open_pager(gbls.interactive);
 	dump_extent_block(out, eb);
@@ -1065,3 +1074,91 @@ static void do_rdump(char **args)
 
 	return ;
 }
+
+/*
+ * do_encode_lockres()
+ *
+ */
+static void do_encode_lockres (char **args)
+{
+	struct ocfs2_dinode *inode;
+	uint64_t blkno;
+	char *buf = NULL;
+	errcode_t ret = 0;
+	char suprlock[50] = "\0";
+	char metalock[50] = "\0";
+	char datalock[50] = "\0";
+	char rdwrlock[50] = "\0";
+
+	if (process_inode_args(args, &blkno))
+		return ;
+
+	if (blkno == OCFS2_SUPER_BLOCK_BLKNO) {
+		ret = ocfs2_encode_lockres(OCFS2_LOCK_TYPE_SUPER, blkno, 0,
+					   suprlock);
+	} else {
+		buf = gbls.blockbuf;
+		ret = ocfs2_read_inode(gbls.fs, blkno, buf);
+		if (!ret) {
+			inode = (struct ocfs2_dinode *)buf;
+			ocfs2_encode_lockres(OCFS2_LOCK_TYPE_META, blkno,
+					     inode->i_generation, metalock);
+			ocfs2_encode_lockres(OCFS2_LOCK_TYPE_DATA, blkno,
+					     inode->i_generation, datalock);
+			ocfs2_encode_lockres(OCFS2_LOCK_TYPE_RW, blkno,
+					     inode->i_generation, rdwrlock);
+		}
+	}
+
+	if (ret) {
+		com_err(args[0], ret, " ");
+		return ;
+	}
+
+	printf("\t");
+	if (*suprlock)
+		printf("%s ", suprlock);
+	if (*metalock)
+		printf("%s ", metalock);
+	if (*datalock)
+		printf("%s ", datalock);
+	if (*rdwrlock)
+		printf("%s ", rdwrlock);
+	printf("\n");
+
+	return ;
+}
+
+/*
+ * do_locate()
+ *
+ */
+static void do_locate(char **args)
+{
+	uint64_t blkno;
+
+	if (process_inode_args(args, &blkno))
+		return ;
+
+	find_inode_paths(gbls.fs, args, blkno, stdout);
+}
+
+/*
+ * do_dump_fs_locks()
+ *
+ */
+static void do_fs_locks(char **args)
+{
+	FILE *out;
+	int dump_lvbs = 0;
+
+	if (check_device_open())
+		return;
+
+	if (args[1] && !strcmp("-l", args[1]))
+		dump_lvbs = 1;
+
+	out = open_pager(gbls.interactive);
+	dump_fs_locks(gbls.fs->uuid_str, out, dump_lvbs);
+	close_pager(out);
+}
